Re: [PATCH 2/2] pack-objects: optimize "recency order"
- From
Ævar Arnfjörð Bjarmason <avarab@gmail.com>
- Date
- Oct 28, 2011, 09:17 UTC
- Message-ID
- <CACBZZX7taoaRWALYd_scf6Z2Hr-xo3voNh=vx8LoPvU8Xo290w@mail.gmail.com>
- In-Reply-To
- <7vy5w6xf7n.fsf@alter.siamese.dyndns.org>
On Fri, Oct 28, 2011 at 00:05, Junio C Hamano <gitster@pobox.com> wrote:
Show 7 quoted lines
> Ævar Arnfjörð Bjarmason <avarab@gmail.com> writes: > >> We recently upgraded to 1.7.7 and I've traced a very large slowdown in >> packing down to this commit. > > Does Dan McGee's series leading to 38d4deb (pack-objects: don't traverse > objects unnecessarily, 2011-10-18) help?
Yes it does!
When I do:
git cherry-pick 703f05ad5835cff92b12c29aecf8d724c8c847e2..38d4deb
Here's the time on the linux-2.6.git repack with that series:
real 0m53.969s
user 0m47.063s
sys 0m3.020sOn the repository I was having troubles with this was the result on master:
Total 911023 (delta 687744), reused 905500 (delta 683064)
real 6m0.487s
user 4m1.751s
sys 1m56.331sAnd with the cherry-pick:
Total 911023 (delta 687744), reused 911023 (delta 687744)
real 1m44.192s
user 0m32.169s
sys 0m4.383sAnd with 1b4bb16b9ec331c91e28d2e3e7dee5070534b6a2 reverted:
Total 911023 (delta 687744), reused 911023 (delta 687744)
real 1m23.796s
user 0m31.931s
sys 0m3.549sSo it's still slower, but not intolerably slower. I'd be interested to find out why we have that 20% difference that doesn't show up on linux-2.6.git though, the repository is mostly source code but there are some binary blobs in it as well, although not very large, the overall size of the entire repository is <500MB.